@@ -27,19 +27,18 @@ function(input, valuename = "r", pchlist = c(19, 17, 15, 1, 5, 2, 7),
     else
     { pchlist = pchlist }
     interval = interval
-d <- as.dist(input)
+    d <- as.dist(input)
     seqn  <- (seq(0, interval^2, by = interval))/(interval^2)
     limit0 <- round((min(d) + (max(d)-min(d))*seqn), digits)
     limit <- limit0[c(-1, -length(limit0))]
-limit <- sort(limit, decreasing = TRUE)
+    limit <- sort(limit, decreasing = TRUE)
 
     matrix <- lower.tri(input)
     plot(x = 0:nrow(matrix),y = 0:nrow(matrix), type = "n", axes = FALSE, xlab="", ylab="") 
     xleft = 0
     ybottom = 0
     for (i in 2:nrow(matrix))
-      for (j in 1:length(matrix[i,][matrix[i,]]))
-      {
+      for (j in 1:length(matrix[i,][matrix[i,]])){
            xleft <-  j - 1
            ybottom <- nrow(matrix) - i
            rect(xleft = xleft, ybottom = ybottom, xright = xleft + 1, ytop = ybottom + 1) 
@@ -49,10 +48,8 @@ limit <- sort(limit, decreasing = TRUE)
               { pch = pchlist[1]}
            if (input[i,j] < limit[length(limit)])
               { pch = pchlist[(length(limit)+1)]}
-           else
-            {
-               for (n in 2:(length(limit)))
-                {
+           else{
+               for (n in 2:(length(limit))){
                     if ( input[i,j] >= limit[n]&input[i,j] < limit[n-1] )
                        { pch = pchlist[n] }
                 }
@@ -60,17 +57,14 @@ limit <- sort(limit, decreasing = TRUE)
            if(size)
            { points(x,y, pch = pch, cex = cex*abs(input[i,j])) }
            else { points(x,y, pch = pch, cex = cex) }
-           if(add.text) 
-           { 
+           if(add.text) { 
              text(x,y+0.25, pch)
              text(x,y-0.25, round(input[i,j], digits))
            }
        }
-      if (add.number)
-       {
+      if (add.number){
             x1 = - 0.5
-            for (textloc in 1:nrow(matrix))
-            {
+            for (textloc in 1:nrow(matrix)){
               x1 <- x1 + 1
               y1 <- nrow(matrix) - textloc + 0.5
               text(x1, y1, as.character(textloc), cex = ncex)
@@ -79,25 +73,21 @@ limit <- sort(limit, decreasing = TRUE)
       if (show.legend)  
        {
     xlegend <- ncol(input)
-        for (k in 0:(length(limit)))  
-         { 
+        for (k in 0:(length(limit)))  { 
              ylegend <- nrow(input) - k * int
              points( ncol(input)*0.6, ylegend, pch = pchlist[k+1] )
-             if (k == 0)
-             {
+             if (k == 0){
               text(xlegend*0.68, ylegend, paste(formatC(sprintf("%.2f",limit[k + 1]), width = 5)))
   text(xlegend*0.76, ylegend, expression(""<=""))
               text(xlegend*0.8,  ylegend, valuename)
              }
-             if (! k == 0 & !k == length(limit))
-             { 
+             if (! k == 0 & !k == length(limit)){ 
               text(xlegend*0.88, ylegend, paste("<", formatC(sprintf("%.2f", limit[k]), width = 5)))
               text(xlegend*0.8,  ylegend, valuename)
               text(xlegend*0.68, ylegend, paste(formatC(sprintf("%.2f", limit[k+1]), width = 5)))
   text(xlegend*0.76, ylegend, expression(""<=""))
               }
-             if (k == length(limit))
-              {
+             if (k == length(limit)){
               text(xlegend*0.88, ylegend , paste("<", formatC(sprintf("%.2f",limit[k]), width = 5)))
               text(xlegend*0.8, ylegend, valuename)
               }
